@@ -12,12 +12,19 @@
 
 #include <SDL.h>
 
+#ifndef __APPLE__
 #include <GL/glew.h>
 #include <GL/gl.h>
+#else
+#include <OpenGL/gl.h>
+static inline void glewInit(void) {}
+#endif
 
 typedef struct {
 	int w, h;
-	SDL_Surface* screen;
+	SDL_Window* window;
+	SDL_GLContext glcontext;
+	int is_fullscreen;
 } gl_ctx;
 
 void ortho(gl_ctx* ctx);
